<?php

namespace Drupal\tmgmt_contentapi\Services;

use Drupal\tmgmt_contentapi\Swagger\Client\Api\JobApi;


/**
 * Service to process job.
 *
 * Acknowledge, update, delete jobs.
 *
 * @category Class
 * @package Drupal\tmgmt_contentapi\Services
 * @author Lionbridge team
 */
class ProcessJobManually {

  /**
   * The request api.
   *
   * @var \Drupal\tmgmt_contentapi\Swagger\Client\Api\JobApi
   */
  protected $jobApi;
  /**
   * The process job service.
   *
   * @var \Drupal\tmgmt_contentapi\Services\ProcessJob
   */
  protected $processJob;
  /**
   * Consructor.
   *
   * @param \Drupal\tmgmt_contentapi\Services\ProcessJob $processJob
   *   Object for file system service.
   */
  public function __construct(
    ProcessJob $processJob,
    ) {
    $this->processJob = $processJob;

  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('tmgmt_contentapi.process_job'),
    );
  }

  /**
   * Function to manually import data from content API by job.
   */
  function importData(TranslatorInterface $translator, JobInterface $job) {
    $capiToken = tmgmt_contentapi_get_capi_token($translator);
    $cttToken = tmgmt_contentapi_get_ctt_token($translator);
    // NEED TO CALL THE NEW ONE.
    $capiJob = tmgmt_contentapi_get_capijob_from_drupaljob($capiToken, $cttToken, $job);
    if ($capiJob['status'] != StatusCodeEnum::REVIEW_TRANSLATION && $capiJob['status'] != StatusCodeEnum::TRANSLATION_APPROVED) {
      return;
    }
    ConentApiHelper::capiJobSetStoredData(
      $capiJob['drupalJob'],
      [
        'jobId' => $capiJob['jobId'],
        'jobStatus' => $capiJob['status'],
        'providerId' => $capiJob['providerId'],
        'jobType' => $capiJob['type'],
        'updateTime' => $capiJob['updateTime']
      ]
    );
    $capiJobs = tmgmt_contentapi_scan_updated_jobs($capiToken, $cttToken, $capiJob['jobId']);
    if (count($capiJobs) == 0) {
      $capiJobs[$capiJob['jobId']] = $capiJob;
    }
    tmgmt_contentapi_downlaod_for_jobs($capiToken, $cttToken, $capiJobs, $translator->isAutoAccept());
  }

  /**
   * Function to get job details.
   */
  function getJobDetailsFromCapi($capiToken, $cttToken, JobInterface $job) {
    $jobapi = new JobApi();
    $prId = GeneralHelper::getCpJobIdfromLocJob($job);
    $requestapi = new RequestApi();
    $jobapi = new JobApi();
    $find_job = $jobapi->FindJob($capiToken, $prId);
    if ($find_job != 200) {
      $requestsarray = $requestapi->jobsJobIdRequestsGetCtt($cttToken, $prId);
      $projectInfo = $jobapi->jobsJobIdGetCtt($cttToken, $prId, "fullWithStats");
      $jobstatus = $projectInfo->getStatusCode()->getStatusCode();
    }
    else {
      $requestsarray = $requestapi->jobsJobIdRequestsGet($capiToken, $prId);
      $projectInfo = $jobapi->jobsJobIdGet($capiToken, $prId, "fullWithStats");
      if ($projectInfo->getStatusCode() != 'COMPLETED') {
        $jobstatus = $jobapi->jobsJobIdGetStatus($capiToken, $prId);
      }
      else {
        $jobstatus = $projectInfo->getStatusCode();
      }
    }
    $requestIds = [];
    foreach ($requestsarray as $request) {
      array_push($requestIds, $request->getRequestId());
    }
    $drupalDateTime = DrupalDateTime::createFromTimestamp(time());
    $updateTime = $drupalDateTime->format("Y-m-d H:i:s:u");
    $jobInfo['type'] = ($find_job != 200 ? 1 : 2);
    $jobInfo['jobId'] = $projectInfo->getJobId();
    $jobInfo['updateId'] = '';
    $jobInfo['requestIds'] = $requestIds;
    $jobInfo['providerId'] = $projectInfo->getProviderId();
    $jobInfo['status'] = $jobstatus;
    $jobInfo['drupalJob'] = $job;
    $jobInfo['updateTime'] = $updateTime;
    return $jobInfo;
  }

  

}
